MessageHeader

Struct MessageHeader 

pub struct MessageHeader {
    pub session_id: SessionId,
    pub stream_id: StreamId,
    pub sequence_nr: SerialNumber16,
    pub client_key: Option<ClientKey>,
}
XRCE Message-Header.

Fields

session_id: SessionId

Session-Identifier; entscheidet ob client_key present ist.

stream_id: StreamId

Stream-Identifier (best-effort/reliable/none).

sequence_nr: SerialNumber16

RFC-1982 16-bit Serial Number (Little-Endian on wire).

client_key: Option<ClientKey>

Optionaler ClientKey — nur bei session_id <= 127.

Implementations

Source

impl MessageHeader

pub const WIRE_SIZE_NO_KEY: usize = 4

Wire-Size ohne ClientKey: 4 Bytes.

pub const WIRE_SIZE_WITH_KEY: usize

Wire-Size mit ClientKey: 8 Bytes.

pub fn without_client_key( session_id: SessionId, stream_id: StreamId, sequence_nr: SerialNumber16, ) -> Result<Self, XrceError>

Konstruktor ohne ClientKey (session_id muss >=128 sein).

Errors

ValueOutOfRange, wenn session_id <= 127 waere — der Header muesste dann einen ClientKey tragen.

pub fn with_client_key( session_id: SessionId, stream_id: StreamId, sequence_nr: SerialNumber16, client_key: ClientKey, ) -> Result<Self, XrceError>

Konstruktor mit ClientKey (session_id muss <=127 sein).

Errors

ValueOutOfRange, wenn session_id >= 128 waere.

pub fn wire_size(&self) -> usize

Wire-Size in Bytes (4 oder 8).

pub fn write_to(&self, out: &mut [u8]) -> Result<usize, XrceError>

Encodiert den Header in den gegebenen Buffer und liefert die geschriebene Anzahl Bytes.

Errors

WriteOverflow, wenn out.len() < wire_size().

pub fn read_from(bytes: &[u8]) -> Result<(Self, usize), XrceError>

Decodiert einen Header aus einem Slice. Liefert (header, bytes_consumed).

Errors

UnexpectedEof, wenn bytes zu kurz fuer die je nach session_id gewaehlte Variante ist.